==> lms-1.4.5+libs.tar.gz: lms/modules/rtqueuedel.php <==
<?php

/*
 * LMS version 1.4.5 Persus
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: rtqueuedel.php,v 1.3.2.2 2005/01/01 19:20:04 alec Exp $
 */

$layout['pagetitle'] = 'Usunicie kolejki ID: '.sprintf("%04d",$_GET['id']);

if (!$LMS->QueueExists($_GET['id']))
{
	$body = '<H1>'.$layout['pagetitle'].'</H1><P>Podany przez Ciebie ID jest bdny bd nie istnieje w bazie danych.</P>';
}else{

	if($_GET['is_sure']!=1)
	{
		$body = '<H1>'.$layout['pagetitle'].'</H1>';
		$body .= '<P>Czy jeste pewien e chcesz usun kolejk '.$LMS->GetQueueName($_GET['id']).'?</P>'; 
		$body .= '<P>Wszystkie dane kolejki zostan utracone, a take wszystkie przypisane do niej zgoszenia i wiadomoci zostan usunite.</P>';
		$body .= '<P><A HREF="?m=rtqueuedel&id='.$_GET['id'].'&is_sure=1">Tak, jestem pewien.</A>&nbsp;';
		$body .= '<A HREF="?'.$_SESSION['backto'].'">Nie, rozmyliem si.</A></P>';
	}
	else
	{
		//$body = "<H1>".$layout['pagetitle']."</H1>";
		//$body .= "<P>Kolejka ".$LMS->GetQueueName($_GET['id'])." zostaa usunita.</P>";
		$LMS->QueueDelete($_GET['id']);
		header('Location: ?m=rtqueuelist');
		die;
	}
}

$SMARTY->display('header.html');
$SMARTY->assign('body',$body);
$SMARTY->display('dialog.html');
$SMARTY->display('footer.html');

?>

==> lms-1.6.1+libs.tar.gz: lms/modules/rtqueuedel.php <==
<?php

/*
 * LMS version 1.6.1 Ishta
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: rtqueuedel.php,v 1.10.2.2 2005/05/20 11:44:42 kondi Exp $
 */

$layout['pagetitle'] = trans('Remove queue ID: $0',sprintf("%04d",$_GET['id']));

if (!$LMS->QueueExists($_GET['id']))
{
	$body = '<H1>'.$layout['pagetitle'].'</H1><P>'.trans('Specified ID is not proper or does not exist!').'</P>';
}else{

	if($_GET['is_sure']!=1)
	{
		$body = '<H1>'.$layout['pagetitle'].'</H1>';
		$body .= '<P>'.trans('Do you want to remove queue called $0?',$LMS->GetQueueName($_GET['id'])).'</P>'; 
		$body .= '<P>'.trans('All tickets and messages in queue will be lost.').'</P>';
		$body .= '<P><A HREF="?m=rtqueuedel&id='.$_GET['id'].'&is_sure=1">'.trans('Yes, I know what I do.').'</A>&nbsp;';
		$body .= '<A HREF="?'.$SESSION->get('backto').'">'.trans('No, I\'ve changed my mind.').'</A></P>';
	}
	else
	{
		//$body = "<H1>".$layout['pagetitle']."</H1>";
		//$body .= "<P>Kolejka ".$LMS->GetQueueName($_GET['id'])." zostaa usunita.</P>";
		$LMS->QueueDelete($_GET['id']);
		$SESSION->redirect('?m=rtqueuelist');
	}
}

$SMARTY->display('header.html');
$SMARTY->assign('body',$body);
$SMARTY->display('dialog.html');
$SMARTY->display('footer.html');

?>
